@@ -4,9 +4,10 @@ from pathlib import Path as _Path
 
 from .bosl2_base import Bosl2Base as _Bosl2Base
 
-_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/transforms.scad'}", use_not_include=False)
+_extra_scad_include(f"{_Path(__file__).parent.parent / 'bosl2/BOSL2/transforms.scad'}", False)
 
 _NO_ARG = _OpenSCADConstant('_NO_ARG')
+_transform = _OpenSCADConstant('_transform')
 class move(_Bosl2Base):
     def __init__(self, v=None, p=None, **kwargs):
        super().__init__("move", {"v" : v, "p" : p, **kwargs})
@@ -52,8 +53,8 @@ class zmove(_Bosl2Base):
        super().__init__("zmove", {"z" : z, "p" : p, **kwargs})
 
 class rot(_Bosl2Base):
-    def __init__(self, a=None, v=None, cp=None, _from=None, to=None, reverse=None, p=None, _m=None, **kwargs):
-       super().__init__("rot", {"a" : a, "v" : v, "cp" : cp, "_from" : _from, "to" : to, "reverse" : reverse, "p" : p, "_m" : _m, **kwargs})
+    def __init__(self, a=None, v=None, cp=None, _from=None, to=None, reverse=None, p=None, **kwargs):
+       super().__init__("rot", {"a" : a, "v" : v, "cp" : cp, "_from" : _from, "to" : to, "reverse" : reverse, "p" : p, **kwargs})
 
 class xrot(_Bosl2Base):
     def __init__(self, a=None, p=None, cp=None, **kwargs):
@@ -67,6 +68,10 @@ class zrot(_Bosl2Base):
     def __init__(self, a=None, p=None, cp=None, **kwargs):
        super().__init__("zrot", {"a" : a, "p" : p, "cp" : cp, **kwargs})
 
+class tilt(_Bosl2Base):
+    def __init__(self, to=None, cp=None, reverse=None, p=None, **kwargs):
+       super().__init__("tilt", {"to" : to, "cp" : cp, "reverse" : reverse, "p" : p, **kwargs})
+
 class scale(_Bosl2Base):
     def __init__(self, v=None, p=None, cp=None, **kwargs):
        super().__init__("scale", {"v" : v, "p" : p, "cp" : cp, **kwargs})
@@ -175,6 +180,10 @@ class zrot(_Bosl2Base):
     def __init__(self, a=None, p=None, cp=None, **kwargs):
        super().__init__("zrot", {"a" : a, "p" : p, "cp" : cp, **kwargs})
 
+class tilt(_Bosl2Base):
+    def __init__(self, to=None, cp=None, reverse=None, **kwargs):
+       super().__init__("tilt", {"to" : to, "cp" : cp, "reverse" : reverse, **kwargs})
+
 class xscale(_Bosl2Base):
     def __init__(self, x=None, p=None, cp=None, **kwargs):
        super().__init__("xscale", {"x" : x, "p" : p, "cp" : cp, **kwargs})
@@ -207,3 +216,19 @@ class skew(_Bosl2Base):
     def __init__(self, p=None, sxy=None, sxz=None, syx=None, syz=None, szx=None, szy=None, axy=None, axz=None, ayx=None, ayz=None, azx=None, azy=None, **kwargs):
        super().__init__("skew", {"p" : p, "sxy" : sxy, "sxz" : sxz, "syx" : syx, "syz" : syz, "szx" : szx, "szy" : szy, "axy" : axy, "axz" : axz, "ayx" : ayx, "ayz" : ayz, "azx" : azx, "azy" : azy, **kwargs})
 
+class translate(_Bosl2Base):
+    def __init__(self, v=None, **kwargs):
+       super().__init__("translate", {"v" : v, **kwargs})
+
+class rotate(_Bosl2Base):
+    def __init__(self, a=None, v=None, **kwargs):
+       super().__init__("rotate", {"a" : a, "v" : v, **kwargs})
+
+class scale(_Bosl2Base):
+    def __init__(self, v=None, **kwargs):
+       super().__init__("scale", {"v" : v, **kwargs})
+
+class multmatrix(_Bosl2Base):
+    def __init__(self, m=None, **kwargs):
+       super().__init__("multmatrix", {"m" : m, **kwargs})
+
